@@ -1,14 +1,10 @@
-# coding: utf-8
-from __future__ import unicode_literals
-
 from .. import Provider as DateTimeProvider
 
 
 class Provider(DateTimeProvider):
 
-    @classmethod
-    def day_of_week(cls):
-        day = cls.date('%w')
+    def day_of_week(self):
+        day = self.date('%w')
         DAY_NAMES = {
             "0": "Dimanche",
             "1": "Lundi",
@@ -20,9 +16,8 @@ class Provider(DateTimeProvider):
         }
         return DAY_NAMES[day]
 
-    @classmethod
-    def month_name(cls):
-        month = cls.month()
+    def month_name(self):
+        month = self.month()
         MONTH_NAMES = {
             "01": "Janvier",
             "02": "Février",
@@ -38,4 +33,3 @@ class Provider(DateTimeProvider):
             "12": "Décembre",
         }
         return MONTH_NAMES[month]
-
